@@ -1,6 +1,6 @@
 /*
     orzaccel
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ orz_accel_class_init (OrzAccelClass *klass)
   GObjectClass *object_class;
 
   parent_class = g_type_class_peek_parent (klass);
-  object_class = (GObjectClass *) klass;
+  object_class = (GObjectClass *)klass;
 
   object_class->dispose = orz_accel_dispose;
 }
@@ -155,6 +155,16 @@ orz_accel_new (void)
 }
 
 
+/*  ja:ウインドウを取得する
+    accel,オブジェクト
+      RET,ウインドウ                                                        */
+GtkWindow *
+orz_accel_get_window (OrzAccel *accel)
+{
+  return accel ? accel->window : NULL;
+}
+
+
 /*  ja:ウインドウを設定する
      accel,オブジェクト
     window,ウインドウ                                                       */
@@ -213,3 +223,13 @@ orz_accel_remove_accel_group (OrzAccel      *accel,
       g_object_unref (accel_group);
     }
 }
+
+
+/*  ja:アクセルグループを取得する
+    accel,オブジェクト
+      RET,アクセルグループのリスト                                          */
+GSList *
+orz_accel_get_accel_group (OrzAccel *accel)
+{
+  return accel ? accel->gslist : NULL;
+}
