@@ -16,8 +16,9 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include "misc/charuty.h"
 #include "orzcharlist.h"
+#include "orzcharset.h"
+#include "misc/charuty.h"
 #include <gdk/gdkkeysyms.h>
 
 
@@ -84,9 +85,9 @@ orz_charlist_class_init (OrzCharlistClass *klass)
   GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
-  gobject_class = (GObjectClass*) klass;
-  object_class = (GtkObjectClass*) klass;
-  widget_class = (GtkWidgetClass*) klass;
+  gobject_class = (GObjectClass *)klass;
+  object_class = (GtkObjectClass *)klass;
+  widget_class = (GtkWidgetClass *)klass;
 
   parent_class = g_type_class_peek_parent (klass);
 
@@ -372,10 +373,17 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist), "delete-event",
                                     G_CALLBACK (orz_charlist_delete), NULL);
   /* ja:ボタン */
+#ifdef G_OS_WIN32
+  charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
+  charlist->cancel_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+#else /* not G_OS_WIN32 */
   charlist->cancel_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
                                         GTK_STOCK_OK, GTK_RESPONSE_OK);
+#endif /* not G_OS_WIN32 */
   /* ja:リストボックス */
   charlist->tview = gtk_tree_view_new_with_model
                     (GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING)));
@@ -523,12 +531,12 @@ orz_charlist_set_charlist (OrzCharlist *charlist,
 /*  ja:文字符号化方式を取得する
     charlist,ウィジェット
          RET,文字符号化方式                                                 */
-/*gchar *
+gchar *
 orz_charlist_get_charset (OrzCharlist *charlist)
 {
   return charlist ? orz_charset_get_charset (ORZ_CHARSET (charlist->charset))
                   : NULL;
-}*/
+}
 
 
 /*  ja:文字符号化方式を設定する
@@ -548,12 +556,12 @@ orz_charlist_set_charset (OrzCharlist *charlist,
 /*  ja:文字符号化方式の候補を取得する
     charlist,ウィジェット
          RET,文字符号化方式の候補                                           */
-/*gchar *
+gchar *
 orz_charlist_get_candidate (OrzCharlist *charlist)
 {
   return charlist
         ? orz_charset_get_candidate (ORZ_CHARSET (charlist->charset)) : NULL;
-}*/
+}
 
 
 /*  ja:文字符号化方式の候補を追加する
@@ -601,10 +609,10 @@ orz_charlist_add_candidate (OrzCharlist *charlist,
      charlist,ウィジェット
     candidate,文字符号化方式のリスト,NULL:すべて削除
           RET,TRUE:正常終了,FALSE:エラー                                    */
-/*gboolean
+gboolean
 orz_charlist_remove_candidate (OrzCharlist *charlist,
                                const gchar *candidate)
 {
   return charlist ? orz_charset_remove_candidate
                         (ORZ_CHARSET (charlist->charset), candidate) : FALSE;
-}*/
+}
