@@ -1,6 +1,6 @@
 /*
     orzhistory
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include "misc/fileio.h"
 #include "orzhistory.h"
+#include "misc/fileio.h"
 
 
 static void orz_history_class_init (OrzHistoryClass *klass);
@@ -81,7 +81,7 @@ orz_history_class_init (OrzHistoryClass *klass)
   GObjectClass *object_class;
 
   parent_class = g_type_class_peek_parent (klass);
-  object_class = (GObjectClass *) klass;
+  object_class = (GObjectClass *)klass;
 
   object_class->dispose = orz_history_dispose;
 
@@ -256,14 +256,33 @@ orz_history_add_file (OrzHistory  *history,
           gchar *label;
           gint length;
           GList *glist;
+          GdkPixbuf *pixbuf;
           GtkWidget *menu_item;
 
           glist = gtk_container_get_children
                                         (GTK_CONTAINER (history->menu_shell));
           length = g_list_length (glist);
+#if GLIB_CHECK_VERSION(2,6,0)
+          label = g_filename_display_name (history_item->file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
           label = g_filename_to_utf8 (history_item->file, -1,
                                                             NULL, NULL, NULL);
-          history_item->menu_item = gtk_menu_item_new_with_label (label);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
+          pixbuf = fileio_extract_icon (history_item->file,
+                                                    FILEIO_ICON_SIZE_SMALL);
+          if (pixbuf)
+            {
+              history_item->menu_item = gtk_image_menu_item_new_with_label
+                                                                    (label);
+              gtk_image_menu_item_set_image
+                                (GTK_IMAGE_MENU_ITEM (history_item->menu_item),
+                                        gtk_image_new_from_pixbuf (pixbuf));
+              g_object_unref (pixbuf);
+            }
+          else
+            {
+              history_item->menu_item = gtk_menu_item_new_with_label (label);
+            }
           g_free (label);
           g_signal_connect (G_OBJECT (history_item->menu_item), "activate",
                             G_CALLBACK (orz_history_activate), history);
@@ -374,6 +393,16 @@ orz_history_get_file (OrzHistory *history)
 }
 
 
+/*  ja:メニューを取得する
+    history,オブジェクト
+        RET,メニュー                                                        */
+GtkWidget *
+orz_history_get_menu (OrzHistory *history)
+{
+  return history ? history->menu_shell : NULL;
+}
+
+
 /*  ja:メニューを設定する
        history,オブジェクト
     menu_shell,メニュー
@@ -381,7 +410,7 @@ orz_history_get_file (OrzHistory *history)
 void
 orz_history_set_menu (OrzHistory *history,
                       GtkWidget  *menu_shell,
-                      gint        position)
+                      const gint  position)
 {
   if (history)
     {
