@@ -38,6 +38,8 @@ void
 property_copy (FileType *ft_dst,
                FileType *ft_src)
 {
+  gboolean success[12];
+
   ft_dst->ft_id = ft_src->ft_id;
   if (ft_dst->crlf < 3 && ft_src->crlf < 3)
     ft_dst->crlf = ft_src->crlf;
@@ -63,6 +65,8 @@ property_copy (FileType *ft_dst,
   g_free (ft_dst->font_name);
   ft_dst->font_name = ft_src->font_name ? g_strdup (ft_src->font_name) : NULL;
   g_memmove (ft_dst->color, ft_src->color, sizeof (GdkColor) * 12);
+  gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                    ft_dst->color, 12, FALSE, TRUE, success);
 }
 
 
@@ -1061,6 +1065,8 @@ property_dialog (GtkWindow *parent,
   result = gtk_dialog_run (GTK_DIALOG (propdlg.dialog)) == GTK_RESPONSE_OK;
   if (result)
     {
+      gboolean success[12];
+
       ft->ft_id = propdlg.ft_id;
       if (propdlg.entry_text)
         {
@@ -1159,6 +1165,8 @@ property_dialog (GtkWindow *parent,
           propdlg.charset_list = NULL;
         }
       g_memmove (ft->color, propdlg.gdk_color, sizeof (GdkColor) * 12);
+      gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                        ft->color, 12, FALSE, TRUE, success);
       g_free (ft->font_name);
 #if GTK_CHECK_VERSION(2,4,0)
       ft->font_name = g_strdup (gtk_font_button_get_font_name
