@@ -120,7 +120,7 @@ MiscCreateMenuEntry menu_entries[] = {
 {"/edit/jump",          GTK_STOCK_JUMP_TO,             "<control>J",  NULL,             MISC_CREATE_MENU_STOCK,                             command_jump,     NULL,                    NULL},
 {"/edit/sep4",          NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
 #if GTK_CHECK_VERSION(2,10,0)
-{"/edit/all",           GTK_STOCK_SELECT_ALL,          "<control>A",  NULL,             MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
+{"/edit/all",           GTK_STOCK_SELECT_ALL,          "<control>A",  NULL,             MISC_CREATE_MENU_STOCK,                             command_all,      NULL,                    NULL},
 #else /* not GTK_CHECK_VERSION(2,10,0) */
 {"/edit/all",           N_("_All"),                    "<control>A",  select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
 #endif /* not GTK_CHECK_VERSION(2,10,0) */
@@ -154,7 +154,7 @@ MiscCreateMenuEntry popup_entries[] = {
 {"/delete",             GTK_STOCK_DELETE,              NULL,          NULL,             MISC_CREATE_MENU_STOCK,                             command_delete,   NULL,                    NULL},
 {"/sep2",               NULL,                          NULL,          NULL,             MISC_CREATE_MENU_SEPARATOR,                         NULL,             NULL,                    NULL},
 #if GTK_CHECK_VERSION(2,10,0)
-{"/all",                GTK_STOCK_SELECT_ALL,          "<control>A",  NULL,             MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
+{"/all",                GTK_STOCK_SELECT_ALL,          "<control>A",  NULL,             MISC_CREATE_MENU_STOCK,                             command_all,      NULL,                    NULL},
 #else /* not GTK_CHECK_VERSION(2,10,0) */
 {"/all",                N_("_All"),                    "<control>A",  select_all16_xpm, MISC_CREATE_MENU_ITEM,                              command_all,      NULL,                    NULL},
 #endif /* not GTK_CHECK_VERSION(2,10,0) */
@@ -192,7 +192,7 @@ int
 main (int   argc,
       char *argv[])
 {
-  gboolean *arg_files;
+  gboolean *arg_files, success[12];
   gchar *group_name, *key, *tmp, *utf8str, *data, *user_config = NULL;
   const gchar *charset;
 #if ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
@@ -492,6 +492,8 @@ main (int   argc,
             {
               g_memmove (ftype[i].color, system_color, sizeof (GdkColor) * 12);
             }
+          gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                    ftype[i].color, 12, FALSE, TRUE, success);
           g_free (group_name);
         }
     }
@@ -592,6 +594,8 @@ TMAID_COPYRIGHT_NOTICE"\n"
                 ? g_strdup_printf ("%s,UTF-8", charset) : g_strdup ("UTF-8");
       /* ja:色 */
       g_memmove (ftype[0].color, system_color, sizeof (GdkColor) * 12);
+      gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                    ftype[0].color, 12, FALSE, TRUE, success);
     }
 
   /* ja:メインウインドウ */
@@ -734,6 +738,8 @@ TMAID_COPYRIGHT_NOTICE"\n"
   system_color[7] = style->mid[0];
   system_color[8] = style->fg[3];
   system_color[9] = style->bg[3];
+  gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                    system_color, 12, FALSE, TRUE, success);
   /* ja:システムフォント */
   system_font = pango_font_description_copy
                                     (pango_context_get_font_description
